@@ -1,8 +1,6 @@
 from uuid import uuid4
 from maelstrom.search import Search
-from maelstrom.tests.account import Account
-from maelstrom.lookup import LookUp
-from maelstrom.data import Data
+from account import Account
 from test import CassandraTestCase
 
 
@@ -12,10 +10,9 @@ class SearchUnitTests(CassandraTestCase):
 
     def setUp(self):
         #CassandraTestCase.setUp(self, ['192.241.181.163', '107.170.88.98'], 'gradfly')
-        CassandraTestCase.setUp(self, ['localhost'], 'test')
-        #Account.rebuild()
-        #Search.rebuild()
-        #LookUp.rebuild()
+        CassandraTestCase.setUp(self, ['127.0.0.1:9160'], 'test')
+        Account.rebuild()
+        Search.rebuild()
         #c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
         '''
         try:
